SimpleYearPickerWidget class

Inheritance

Constructors

SimpleYearPickerWidget({Key? key, required DateTime yearDateTime, required dynamic onChangedCallback(int), int firstYear = 1900, int lastYear = 2100, Decoration? decoration, bool looping = true, EdgeInsetsGeometry padding = EdgeInsets.zero, double width = 400, double height = 350, double? yearWidth, double yearHeight = 250, Decoration? pickerDecoration, Color pickerBackgroundColor = Colors.white, double itemHeight = 60, Alignment textAlignment = Alignment.center, TextStyle? textStyle, double buttonHeight = 60, double todayButtonWidth = 200, Color todayButtonColor = Colors.white, Decoration? todayButtonDecoration, String todayButtonText = 'TODAY', TextStyle? todayButtonTextStyle = const TextStyle(color: Colors.black), double doneButtonWidth = 200, Color doneButtonColor = Colors.white, Decoration? doneButtonDecoration, String doneButtonText = 'DONE', TextStyle? doneButtonTextStyle = const TextStyle(color: Colors.black)})
const

Properties

buttonHeight → double
final
decoration → Decoration?
final
doneButtonColor → Color
final
doneButtonDecoration → Decoration?
final
doneButtonText → String
final
doneButtonTextStyle → TextStyle?
final
doneButtonWidth → double
final
firstYear → int
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
itemHeight → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lastYear → int
final
looping → bool
final
onChangedCallback → dynamic Function(int)
final
padding → EdgeInsetsGeometry
final
pickerBackgroundColor → Color
final
pickerDecoration → Decoration?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAlignment → Alignment
final
textStyle → TextStyle?
final
todayButtonColor → Color
final
todayButtonDecoration → Decoration?
final
todayButtonText → String
final
todayButtonTextStyle → TextStyle?
final
todayButtonWidth → double
final
width → double
final
yearDateTime → DateTime
final
yearHeight → double
final
yearWidth → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited